@@ -2,9 +2,10 @@
 from __future__ import unicode_literals, division, absolute_import
 import re
 import logging
+
 from flexget.entry import Entry
 from flexget.utils.cached_input import cached
-from flexget.plugin import register_plugin, internet
+from flexget.plugin import register_plugin, internet, PluginError
 
 log = logging.getLogger('text')
 
@@ -57,7 +58,10 @@ class Text(object):
     @internet(log)
     def on_task_input(self, task, config):
         url = config['url']
-        request = task.requests.get(url)
+        if '://' in url:
+            lines = task.requests.get(url).iter_lines()
+        else:
+            lines = open(url, 'rb').readlines()
 
         entry_config = config.get('entry')
         format_config = config.get('format', {})
@@ -68,7 +72,7 @@ class Text(object):
         entry = Entry()
 
         # now parse text
-        for line in request.iter_lines():
+        for line in lines:
             for field, regexp in entry_config.iteritems():
                 #log.debug('search field: %s regexp: %s' % (field, regexp))
                 match = re.search(regexp, line)
@@ -87,7 +91,11 @@ class Text(object):
                         used = {}
 
                     # add field to entry
-                    entry[field] = match.group(1)
+                    try:
+                        entry[field] = match.group(1)
+                    except IndexError:
+                        log.error('regex for field `%s` must contain a capture group' % field)
+                        raise PluginError('Your text plugin config contains errors, please correct them.')
                     used[field] = True
                     log.debug('found field: %s value: %s' % (field, entry[field]))
 
